==> setux_managers-0.21.39.2.tar.gz: setux_managers-0.21.39.2/setux/managers/common/package/pip.py <==
from setux.logger import error, info
from setux.core.package import CommonPackager

from setux.managers.common.package.pypi import Pypi


# pylint: disable=no-member


class Distro(CommonPackager):
    '''Python Packages managment
    '''
    manager = 'pip'
    pkgmap = dict()

    def do_init(self):
        self.target.distro.Package.install('setuptools')
        pip = self.target.distro.pkgmap.get('pip')
        if pip:
            self.target.distro.Package.install(pip)
        else:
            self.run(f'python -m ensurepip --upgrade')

    def do_install(self, pkg, ver=None):
        ret, out, err = self.run(f'pip3 install -qU {pkg}')
        for o in out:
            if 'already satisfied' in o:
                break
            if 'Successfully installed' in o:
                info('\t--> %s %s', pkg, ver or '')
                break
        else:
            if any(line.strip() for line in out):
                error('\n'.join(out))

    def do_installed(self, pattern=None):
        ret, out, err = self.run('pip3 list')
        for line in out[2:]:
            try:
                n, v = line.split()
                v = v.replace('(', '')
                v = v.replace(')', '')
                yield n, v
            except:
                error(line)

    def do_installable_cache(self):
        Pypi(self).cache()

    def do_installable(self, pattern):
        yield from Pypi(self).search(pattern)

    def do_remove(self, pkg):
        self.run(f'pip3 uninstall -y {pkg}')

    def do_cleanup(self):
        raise NotImplemented

    def do_update(self):
        raise NotImplemented

==> setux_managers-0.21.43.0.tar.gz: setux_managers-0.21.43.0/setux/managers/common/package/pip.py <==
from setux.logger import error, info
from setux.core.package import CommonPackager

from setux.managers.common.package.pypi import Pypi


# pylint: disable=no-member


class Distro(CommonPackager):
    '''Python Packages managment
    '''
    manager = 'pip'
    pkgmap = dict()

    def do_init(self):
        if self.target.login.name!='root':
            return
        self.target.distro.Package.install('setuptools')
        pip = self.target.distro.pkgmap.get('pip')
        if pip:
            self.target.distro.Package.install(pip)
        else:
            self.run(f'python -m ensurepip --upgrade')

    def do_install(self, pkg, ver=None):
        ret, out, err = self.run(f'pip3 install -qU {pkg}')
        for o in out:
            if 'already satisfied' in o:
                return True
            if 'Successfully installed' in o:
                info('\t++> %s %s', pkg, ver or '')
                return True
        else:
            if any(line.strip() for line in out):
                error('\n'.join(out))
        return False

    def do_installed(self, pattern=None):
        ret, out, err = self.run('pip3 list')
        for line in out[2:]:
            try:
                n, v = line.split()
                v = v.replace('(', '')
                v = v.replace(')', '')
                yield n, v
            except:
                error(line)

    def do_installable_cache(self):
        Pypi(self).cache()

    def do_installable(self, pattern):
        yield from Pypi(self).search(pattern)

    def do_remove(self, pkg):
        self.run(f'pip3 uninstall -y {pkg}')

    def do_cleanup(self):
        raise NotImplemented

    def do_update(self):
        raise NotImplemented
